use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
49699333
Alders
Alders'
Authen
HOTP
John
Kincaid
Kurt
OATH
OTP
Olaf
TOTP
Timestep
Wittkoski
dependabot
hotp
jwittkoski
kurt
lib
olaf
sifukurt
timestep
totp
